/* Automatically generated file - DO NOT EDIT */
static const char psz_license[] =
"                    GNU GENERAL PUBLIC LICENSE\n"
"                       Version 2, June 1991\n"
"\n"
" Copyright (C) 1989, 1991 Free Software Foundation, Inc.,\n"
" 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA\n"
" Everyone is permitted to copy and distribute verbatim copies\n"
" of this license document, but changing it is not allowed.\n"
"\n"
"                            Preamble\n"
"\n"
"  The licenses for most software are designed to take away your\n"
"freedom to share and change it.  By contrast, the GNU General Public\n"
"License is intended to guarantee your freedom to share and change free\n"
"software--to make sure the software is free for all its users.  This\n"
"General Public License applies to most of the Free Software\n"
"Foundation's software and to any other program whose authors commit to\n"
"using it.  (Some other Free Software Foundation software is covered by\n"
"the GNU Lesser General Public License instead.)  You can apply it to\n"
"your programs, too.\n"
"\n"
"  When we speak of free software, we are referring to freedom, not\n"
"price.  Our General Public Licenses are designed to make sure that you\n"
"have the freedom to distribute copies of free software (and charge for\n"
"this service if you wish), that you receive source code or can get it\n"
"if you want it, that you can change the software or use pieces of it\n"
"in new free programs; and that you know you can do these things.\n"
"\n"
"  To protect your rights, we need to make restrictions that forbid\n"
"anyone to deny you these rights or to ask you to surrender the rights.\n"
"These restrictions translate to certain responsibilities for you if you\n"
"distribute copies of the software, or if you modify it.\n"
"\n"
"  For example, if you distribute copies of such a program, whether\n"
"gratis or for a fee, you must give the recipients all the rights that\n"
"you have.  You must make sure that they, too, receive or can get the\n"
"source code.  And you must show them these terms so they know their\n"
"rights.\n"
"\n"
"  We protect your rights with two steps: (1) copyright the software, and\n"
"(2) offer you this license which gives you legal permission to copy,\n"
"distribute and/or modify the software.\n"
"\n"
"  Also, for each author's protection and ours, we want to make certain\n"
"that everyone understands that there is no warranty for this free\n"
"software.  If the software is modified by someone else and passed on, we\n"
"want its recipients to know that what they have is not the original, so\n"
"that any problems introduced by others will not reflect on the original\n"
"authors' reputations.\n"
"\n"
"  Finally, any free program is threatened constantly by software\n"
"patents.  We wish to avoid the danger that redistributors of a free\n"
"program will individually obtain patent licenses, in effect making the\n"
"program proprietary.  To prevent this, we have made it clear that any\n"
"patent must be licensed for everyone's free use or not licensed at all.\n"
"\n"
"  The precise terms and conditions for copying, distribution and\n"
"modification follow.\n"
"\n"
"                    GNU GENERAL PUBLIC LICENSE\n"
"   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION\n"
"\n"
"  0. This License applies to any program or other work which contains\n"
"a notice placed by the copyright holder saying it may be distributed\n"
"under the terms of this General Public License.  The \"Program\", below,\n"
"refers to any such program or work, and a \"work based on the Program\"\n"
"means either the Program or any derivative work under copyright law:\n"
"that is to say, a work containing the Program or a portion of it,\n"
"either verbatim or with modifications and/or translated into another\n"
"language.  (Hereinafter, translation is included without limitation in\n"
"the term \"modification\".)  Each licensee is addressed as \"you\".\n"
"\n"
"Activities other than copying, distribution and modification are not\n"
"covered by this License; they are outside its scope.  The act of\n"
"running the Program is not restricted, and the output from the Program\n"
"is covered only if its contents constitute a work based on the\n"
"Program (independent of having been made by running the Program).\n"
"Whether that is true depends on what the Program does.\n"
"\n"
"  1. You may copy and distribute verbatim copies of the Program's\n"
"source code as you receive it, in any medium, provided that you\n"
"conspicuously and appropriately publish on each copy an appropriate\n"
"copyright notice and disclaimer of warranty; keep intact all the\n"
"notices that refer to this License and to the absence of any warranty;\n"
"and give any other recipients of the Program a copy of this License\n"
"along with the Program.\n"
"\n"
"You may charge a fee for the physical act of transferring a copy, and\n"
"you may at your option offer warranty protection in exchange for a fee.\n"
"\n"
"  2. You may modify your copy or copies of the Program or any portion\n"
"of it, thus forming a work based on the Program, and copy and\n"
"distribute such modifications or work under the terms of Section 1\n"
"above, provided that you also meet all of these conditions:\n"
"\n"
"    a) You must cause the modified files to carry prominent notices\n"
"    stating that you changed the files and the date of any change.\n"
"\n"
"    b) You must cause any work that you distribute or publish, that in\n"
"    whole or in part contains or is derived from the Program or any\n"
"    part thereof, to be licensed as a whole at no charge to all third\n"
"    parties under the terms of this License.\n"
"\n"
"    c) If the modified program normally reads commands interactively\n"
"    when run, you must cause it, when started running for such\n"
"    interactive use in the most ordinary way, to print or display an\n"
"    announcement including an appropriate copyright notice and a\n"
"    notice that there is no warranty (or else, saying that you provide\n"
"    a warranty) and that users may redistribute the program under\n"
"    these conditions, and telling the user how to view a copy of this\n"
"    License.  (Exception: if the Program itself is interactive but\n"
"    does not normally print such an announcement, your work based on\n"
"    the Program is not required to print an announcement.)\n"
"\n"
"These requirements apply to the modified work as a whole.  If\n"
"identifiable sections of that work are not derived from the Program,\n"
"and can be reasonably considered independent and separate works in\n"
"themselves, then this License, and its terms, do not apply to those\n"
"sections when you distribute them as separate works.  But when you\n"
"distribute the same sections as part of a whole which is a work based\n"
"on the Program, the distribution of the whole must be on the terms of\n"
"this License, whose permissions for other licensees extend to the\n"
"entire whole, and thus to each and every part regardless of who wrote it.\n"
"\n"
"Thus, it is not the intent of this section to claim rights or contest\n"
"your rights to work written entirely by you; rather, the intent is to\n"
"exercise the right to control the distribution of derivative or\n"
"collective works based on the Program.\n"
"\n"
"In addition, mere aggregation of another work not based on the Program\n"
"with the Program (or with a work based on the Program) on a volume of\n"
"a storage or distribution medium does not bring the other work under\n"
"the scope of this License.\n"
"\n"
"  3. You may copy and distribute the Program (or a work based on it,\n"
"under Section 2) in object code or executable form under the terms of\n"
"Sections 1 and 2 above provided that you also do one of the following:\n"
"\n"
"    a) Accompany it with the complete corresponding machine-readable\n"
"    source code, which must be distributed under the terms of Sections\n"
"    1 and 2 above on a medium customarily used for software interchange; or,\n"
"\n"
"    b) Accompany it with a written offer, valid for at least three\n"
"    years, to give any third party, for a charge no more than your\n"
"    cost of physically performing source distribution, a complete\n"
"    machine-readable copy of the corresponding source code, to be\n"
"    distributed under the terms of Sections 1 and 2 above on a medium\n"
"    customarily used for software interchange; or,\n"
"\n"
"    c) Accompany it with the information you received as to the offer\n"
"    to distribute corresponding source code.  (This alternative is\n"
"    allowed only for noncommercial distribution and only if you\n"
"    received the program in object code or executable form with such\n"
"    an offer, in accord with Subsection b above.)\n"
"\n"
"The source code for a work means the preferred form of the work for\n"
"making modifications to it.  For an executable work, complete source\n"
"code means all the source code for all modules it contains, plus any\n"
"associated interface definition files, plus the scripts used to\n"
"control compilation and installation of the executable.  However, as a\n"
"special exception, the source code distributed need not include\n"
"anything that is normally distributed (in either source or binary\n"
"form) with the major components (compiler, kernel, and so on) of the\n"
"operating system on which the executable runs, unless that component\n"
"itself accompanies the executable.\n"
"\n"
"If distribution of executable or object code is made by offering\n"
"access to copy from a designated place, then offering equivalent\n"
"access to copy the source code from the same place counts as\n"
"distribution of the source code, even though third parties are not\n"
"compelled to copy the source along with the object code.\n"
"\n"
"  4. You may not copy, modify, sublicense, or distribute the Program\n"
"except as expressly provided under this License.  Any attempt\n"
"otherwise to copy, modify, sublicense or distribute the Program is\n"
"void, and will automatically terminate your rights under this License.\n"
"However, parties who have received copies, or rights, from you under\n"
"this License will not have their licenses terminated so long as such\n"
"parties remain in full compliance.\n"
"\n"
"  5. You are not required to accept this License, since you have not\n"
"signed it.  However, nothing else grants you permission to modify or\n"
"distribute the Program or its derivative works.  These actions are\n"
"prohibited by law if you do not accept this License.  Therefore, by\n"
"modifying or distributing the Program (or any work based on the\n"
"Program), you indicate your acceptance of this License to do so, and\n"
"all its terms and conditions for copying, distributing or modifying\n"
"the Program or works based on it.\n"
"\n"
"  6. Each time you redistribute the Program (or any work based on the\n"
"Program), the recipient automatically receives a license from the\n"
"original licensor to copy, distribute or modify the Program subject to\n"
"these terms and conditions.  You may not impose any further\n"
"restrictions on the recipients' exercise of the rights granted herein.\n"
"You are not responsible for enforcing compliance by third parties to\n"
"this License.\n"
"\n"
"  7. If, as a consequence of a court judgment or allegation of patent\n"
"infringement or for any other reason (not limited to patent issues),\n"
"conditions are imposed on you (whether by court order, agreement or\n"
"otherwise) that contradict the conditions of this License, they do not\n"
"excuse you from the conditions of this License.  If you cannot\n"
"distribute so as to satisfy simultaneously your obligations under this\n"
"License and any other pertinent obligations, then as a consequence you\n"
"may not distribute the Program at all.  For example, if a patent\n"
"license would not permit royalty-free redistribution of the Program by\n"
"all those who receive copies directly or indirectly through you, then\n"
"the only way you could satisfy both it and this License would be to\n"
"refrain entirely from distribution of the Program.\n"
"\n"
"If any portion of this section is held invalid or unenforceable under\n"
"any particular circumstance, the balance of the section is intended to\n"
"apply and the section as a whole is intended to apply in other\n"
"circumstances.\n"
"\n"
"It is not the purpose of this section to induce you to infringe any\n"
"patents or other property right claims or to contest validity of any\n"
"such claims; this section has the sole purpose of protecting the\n"
"integrity of the free software distribution system, which is\n"
"implemented by public license practices.  Many people have made\n"
"generous contributions to the wide range of software distributed\n"
"through that system in reliance on consistent application of that\n"
"system; it is up to the author/donor to decide if he or she is willing\n"
"to distribute software through any other system and a licensee cannot\n"
"impose that choice.\n"
"\n"
"This section is intended to make thoroughly clear what is believed to\n"
"be a consequence of the rest of this License.\n"
"\n"
"  8. If the distribution and/or use of the Program is restricted in\n"
"certain countries either by patents or by copyrighted interfaces, the\n"
"original copyright holder who places the Program under this License\n"
"may add an explicit geographical distribution limitation excluding\n"
"those countries, so that distribution is permitted only in or among\n"
"countries not thus excluded.  In such case, this License incorporates\n"
"the limitation as if written in the body of this License.\n"
"\n"
"  9. The Free Software Foundation may publish revised and/or new versions\n"
"of the General Public License from time to time.  Such new versions will\n"
"be similar in spirit to the present version, but may differ in detail to\n"
"address new problems or concerns.\n"
"\n"
"Each version is given a distinguishing version number.  If the Program\n"
"specifies a version number of this License which applies to it and \"any\n"
"later version\", you have the option of following the terms and conditions\n"
"either of that version or of any later version published by the Free\n"
"Software Foundation.  If the Program does not specify a version number of\n"
"this License, you may choose any version ever published by the Free Software\n"
"Foundation.\n"
"\n"
"  10. If you wish to incorporate parts of the Program into other free\n"
"programs whose distribution conditions are different, write to the author\n"
"to ask for permission.  For software which is copyrighted by the Free\n"
"Software Foundation, write to the Free Software Foundation; we sometimes\n"
"make exceptions for this.  Our decision will be guided by the two goals\n"
"of preserving the free status of all derivatives of our free software and\n"
"of promoting the sharing and reuse of software generally.\n"
"\n"
"                            NO WARRANTY\n"
"\n"
"  11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY\n"
"FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.  EXCEPT WHEN\n"
"OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES\n"
"PROVIDE THE PROGRAM \"AS IS\" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED\n"
"OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF\n"
"MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE RISK AS\n"
"TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.  SHOULD THE\n"
"PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,\n"
"REPAIR OR CORRECTION.\n"
"\n"
"  12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING\n"
"WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR\n"
"REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES,\n"
"INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING\n"
"OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED\n"
"TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY\n"
"YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER\n"
"PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE\n"
"POSSIBILITY OF SUCH DAMAGES.\n"
"\n"
"                     END OF TERMS AND CONDITIONS\n"
"\n"
"            How to Apply These Terms to Your New Programs\n"
"\n"
"  If you develop a new program, and you want it to be of the greatest\n"
"possible use to the public, the best way to achieve this is to make it\n"
"free software which everyone can redistribute and change under these terms.\n"
"\n"
"  To do so, attach the following notices to the program.  It is safest\n"
"to attach them to the start of each source file to most effectively\n"
"convey the exclusion of warranty; and each file should have at least\n"
"the \"copyright\" line and a pointer to where the full notice is found.\n"
"\n"
"    <one line to give the program's name and a brief idea of what it does.>\n"
"    Copyright (C) <year>  <name of author>\n"
"\n"
"    This program is free software; you can redistribute it and/or modify\n"
"    it under the terms of the GNU General Public License as published by\n"
"    the Free Software Foundation; either version 2 of the License, or\n"
"    (at your option) any later version.\n"
"\n"
"    This program is distributed in the hope that it will be useful,\n"
"    but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
"    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
"    GNU General Public License for more details.\n"
"\n"
"    You should have received a copy of the GNU General Public License along\n"
"    with this program; if not, write to the Free Software Foundation, Inc.,\n"
"    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.\n"
"\n"
"Also add information on how to contact you by electronic and paper mail.\n"
"\n"
"If the program is interactive, make it output a short notice like this\n"
"when it starts in an interactive mode:\n"
"\n"
"    Gnomovision version 69, Copyright (C) year name of author\n"
"    Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w'.\n"
"    This is free software, and you are welcome to redistribute it\n"
"    under certain conditions; type `show c' for details.\n"
"\n"
"The hypothetical commands `show w' and `show c' should show the appropriate\n"
"parts of the General Public License.  Of course, the commands you use may\n"
"be called something other than `show w' and `show c'; they could even be\n"
"mouse-clicks or menu items--whatever suits your program.\n"
"\n"
"You should also get your employer (if you work as a programmer) or your\n"
"school, if any, to sign a \"copyright disclaimer\" for the program, if\n"
"necessary.  Here is a sample; alter the names:\n"
"\n"
"  Yoyodyne, Inc., hereby disclaims all copyright interest in the program\n"
"  `Gnomovision' (which makes passes at compilers) written by James Hacker.\n"
"\n"
"  <signature of Ty Coon>, 1 April 1989\n"
"  Ty Coon, President of Vice\n"
"\n"
"This General Public License does not permit incorporating your program into\n"
"proprietary programs.  If your program is a subroutine library, you may\n"
"consider it more useful to permit linking proprietary applications with the\n"
"library.  If this is what you want to do, use the GNU Lesser General\n"
"Public License instead of this License.\n"
;
static const char psz_thanks[] =
"Some VLC plugins use external libraries and make extensive use of the\n"
"following persons' or companies' code:\n"
"\n"
"FAAD2 - Copyright (c) Nero AG, www.nero.com\" - GPLv2 or later\n"
"FFmpeg - Copyright (c) 2000-2017 the FFmpeg developers - LGPLv2.1 or later\n"
"FluidLite - Copyright (c) 2016 Robin Lobel - LGPLv2.1 or later\n"
"FluidSynth - Copyright (c) 2003-2010 Peter Hanappe, Conrad Berhörster, Antoine\n"
"   Schmitt, Pedro López-Cabanillas, Josh Green, David Henningsson - LGPLv2.1 or\n"
"   later\n"
"Fontconfig - Copyright (c) 2000,2001,2002,2003,2004,2006,2007 Keith Packard,\n"
"   (c) 2005 Patrick Lam, (c) 2009 Roozbeh Pournader, (c) 2008,2009 Red Hat,\n"
"   Inc., (c) 2008 Danilo Šegan, (c) 2012 Google, Inc. - MIT License\n"
"freetype - David Turner, Robert Wilhelm, and Werner Lemberg - FreeType License\n"
"GSM - Copyright (c) 1992 - 1994, 2009 Jutta Degener & Carsten Bormann - GSM\n"
"   permissive license\n"
"GNU FriBidi - Copyright (c) 2004-2012 Behdad Esfahbod, Dov Grobgeld, Roozbeh\n"
"   Pournader - LGPLv2.1 or later\n"
"GnuTLS - Copyright (C) 2000-2012 Free Software Foundation, Inc. - LGPLv2.1 or\n"
"   later\n"
"harfbuzz - Copyright (c) 2010, 2011, 2012  Google, Inc., (c) 2012  Mozilla\n"
"   Foundation, (c) 2011 Codethink Limited, (c) 2008, 2010  Nokia Corporation\n"
"   and/or its subsidiary(-ies), (c) 2009 Keith Stribley, (c) 2009 Martin Hosken\n"
"   and SIL International, (c) 2007 Chris Wilson, (c) 2006 Behdad Esfahbod,\n"
"   (c) 2005 David Turner, (c) 2004, 2007, 2008, 2009, 2010 Red Hat, Inc.,\n"
"   (c) 1998-2004 David Turner and Werner Lemberg - Old MIT License\n"
"liba52 - Aaron Holtzman & Michel Lespinasse, et al. - GPLv2 or later\n"
"libav - Copyright (c) 2000 - 2015 the libav developers - LGPLv2.1 or later\n"
"libass - Copyright (c) 2006-2015 Grigori Goronzy et al. - ISC License\n"
"libbluray - Copyright (c) 2009-2015 VideoLAN and authors - LGPLv2.1 or later\n"
"libcaca - Copyright (c) 2004 Sam Hocevar - WTFPL / LGPLv2.1 or later /\n"
"   GPLv2 or later / ISC\n"
"libdca - Copyright (c) 2004-2007 VideoLAN and authors - GPLv2 or later\n"
"libdvbpsi - Copyright (c) 2001-2017 VideoLAN and authors - LGPLv2.1 or later\n"
"libdvdcss - Copyright (c) 2001-2017 VideoLAN and authors - GPLv2 or later\n"
"libdvdread - GPLv2 or later\n"
"libdvdnav - GPLv2 or later\n"
"libebml - Copyright (c) 2002-2015 Steve Lhomme - LGPLv2.1 or later\n"
"libFLAC - Copyright (c) 2001 - 2014 Josh Coalson et al. - Xiph.org BSD license\n"
"libgme - LGPLv2.1 or later\n"
"libgpg-error - Copyright 2003, 2004, 2005, 2006, 2007, 2013 g10 Code GmbH\n"
"   - LGPLv2.1 or later\n"
"libkate - Copyright (c) 2008-2011 Vincent Penquerc'h - 3-clause BSD License\n"
"liblive555 - Copyright (c) 1996-2015 Live Networks, Inc. - LGPLv2.1 or later\n"
"libmad - Copyright (c) 2000-2004 Robert Leslie, et al. - GPLv2 or later\n"
"libmatroska - Copyright (c) 2002-2015 Steve Lhomme - LGPLv2.1 or later\n"
"libmpeg2 - Aaron Holtzman & Michel Lespinasse, et al. - GPLv2 or later\n"
"libmodplug - Oliver Lapicque, Konstanty - Public domain\n"
"libogg, libvorbis - Copyright (c) 2002-2015 Xiph.org Foundation - Xiph.org BSD\n"
"   license\n"
"libpostproc - Copyright (C) 2001-2015 Michael Niedermayer, et al. - GPLv2 or\n"
"   later\n"
"libpng - Copyright (c) 2004, 2006-2014 Glenn Randers-Perhson, et al. - libpng\n"
"   license\n"
"libsamplerate - Copyright (c) 2002-2011 Erik de Castro Lopo - GPLv2 or later\n"
"libschroedinger - Copyright (c) 2006 BBC and Fluendo - MIT License\n"
"libsdl - Copyright (c) 1997-2014 Sam Lantinga et al. - LGPLv2.1 or later\n"
"libshout - Copyright (c) 2012 - LGPLv2.1 or later\n"
"libtheora - Copyright (c) Xiph.org Foundation - Xiph.org BSD license\n"
"libtiff - Copyright (c) 1988-1997 Sam Leffler, (c) 1991-1997 Silicon Graphics,\n"
"   Inc. - BSD-like\n"
"libtwolame - Copyright (c) 2001-2004 Michael Cheng, (c) 2004-2006 The TwoLAME\n"
"   Project - LGPLv2.1 or later\n"
"libupnp - Copyright (c) 2000-2003 Intel Corporation - 3-clause BSD License\n"
"libvpx - Copyright (c) 2010-2015, Google Inc. - 3-clause BSD License\n"
"libxml2 - Copyright (c) 1998-2014 Daniel Veillard - MIT License\n"
"lua - Copyright (c) 1994-2008 Lua.org, PUC-Rio. - MIT License\n"
"Musepack decoder library - Copyright (c) 2005-2011, The Musepack Development\n"
"   Team - 3-clause BSD License\n"
"OpenJPEG - Copyright (c) 2002-2014, Communcations and Remote Sensing\n"
"   Laboratory, UCL, Belgium - ISC License\n"
"Opus - Copyright 2001-2013 Xiph.Org, Skype Limited, Octasic, Jean-Marc Valin,\n"
"   Timothy B. Terriberry, CSIRO, Gregory Maxwell, Mark Borgerding,\n"
"   Erik de Castro Lopo - Xiph.org BSD License\n"
"Sparkle — Andy Matuschak et al. - MIT License\n"
"Speex, Speexdsp - Copyright (c) 1992-2015 Xiph.org Foundation, Jean-Marc Valin,\n"
"   Analog Devices Inc. Commonwealth Scientific and Industrial Research\n"
"   Organisation, David Row, Jutta Degener, Carsten Bormann - 3-clause BSD\n"
"   License\n"
"taglib - Copyright (c) 2004-2016 Scott Wheeler, et al. - LGPLv2.1 or later\n"
"x264 - Copyright (c) 2004-2017 VideoLAN and authors - GPLv2 or later\n"
"x265 - Copyright (c) 2004-2015 x265 project - GPLv2 or later\n"
"Zapping VBI library - Copyright (c) 2000-2003 Michael H. Schimek, Iñaki García\n"
"   Etxebarria - LGPLv2.1 or later\n"
"zlib - Copyright (c) 1995-2017 Jean-loup Gailly and Mark Adler - zlib license\n"
"\n"
"The VideoLAN team would like to thank the following donators:\n"
"\n"
"Julian Cain, who made a $1000 donation\n"
"The French website MacBidouille gave €500 to help us buy a PowerMac G5\n"
"The French magazine à vos MAC gave €500 to help us buy a PowerMac G5\n"
"Laurent Dupuy, who made a €540 donation\n"
"The French company Cybervia (Actech) gave €2000 to pay for webserver hosting\n"
"Dennis Perov - Hardware donation\n"
"\n"
"...the following active members of our user community:\n"
"\n"
"Alan Wright\n"
"David J LaBarre \"DJ\"\n"
"Eric Adler\n"
"Julien Bouquillon\n"
"\n"
"...and code auditors and testers:\n"
"\n"
"David Thiel\n"
"Philippe A. aka \"Lotesdelère\"\n"
"Sebastien Chaumat\n"
;
static const char psz_authors[] =
"VideoLAN and the VLC team would like to acknowledge the following contributors:\n"
"\n"
"Programming\n"
"-----------\n"
"Rémi Denis-Courmont\n"
"Jean-Baptiste Kempf\n"
"Laurent Aimar\n"
"François Cartegnie\n"
"Gildas Bazin\n"
"Felix Paul Kühne\n"
"Rafaël Carré\n"
"Pierre d'Herbemont\n"
"Thomas Guillem\n"
"Rémi Duraffort\n"
"Derk-Jan Hartman\n"
"Antoine Cellerier\n"
"Samuel Hocevar\n"
"Jean-Paul Saman\n"
"Steve Lhomme\n"
"Christophe Mutricy\n"
"Clément Stenac\n"
"Christophe Massiot\n"
"Ilkka Ollakka\n"
"Pierre Ynard\n"
"Filip Roséen\n"
"Damien Fouilleul\n"
"Sigmund Augdal Helberg\n"
"Erwan Tulou\n"
"David Fuhrmann\n"
"Marvin Scholz\n"
"Olivier Teulière\n"
"Cyril Deguet\n"
"Eric Petit\n"
"Filippo Carone\n"
"Rocky Bernstein\n"
"Hugo Beauzée-Luyssen\n"
"Olivier Aubert\n"
"Pavlov Konstantin\n"
"Jakob Leben\n"
"Benjamin Pracht\n"
"Jean-Philippe André\n"
"Stéphane Borel\n"
"JP Dinger\n"
"Geoffroy Couprie\n"
"Martin Storsjö\n"
"Marian Ďurkovič\n"
"Ludovic Fauvet\n"
"Petri Hintukainen\n"
"Yoann Peronneau\n"
"Denis Charmet\n"
"Sébastien Escudier\n"
"Jon Lech Johansen\n"
"KO Myung-Hun\n"
"Edward Wang\n"
"Dennis van Amerongen\n"
"Faustino Osuna\n"
"Mirsal Ennaime\n"
"Sean McGovern\n"
"Jérôme Decoodt\n"
"Loïc Minier\n"
"David Flynn\n"
"Frédéric Yhuel\n"
"Kaarlo Raiha\n"
"Mark Moriarty\n"
"Christopher Mueller\n"
"Fabio Ritrovato\n"
"Tony Castley\n"
"Srikanth Raju\n"
"Michel Kaempf\n"
"Jean-Marc Dressler\n"
"Johan Bilien\n"
"Vincent Seguin\n"
"Simon Latapie\n"
"Bernie Purcell\n"
"Henri Fallon\n"
"Sebastien Zwickert\n"
"Christoph Miebach\n"
"Adrien Maglo\n"
"Emmanuel Puig\n"
"Renaud Dartus\n"
"Alexis de Lattre\n"
"Vincent Penquerc'h\n"
"Arnaud de Bossoreille de Ribou\n"
"Mohammed Adnène Trojette\n"
"Salah-Eddin Shaban\n"
"Vittorio Giovara\n"
"Boris Dorès\n"
"Jai Menon\n"
"Anil Daoud\n"
"Daniel Mierswa\n"
"Naohiro Koriyama\n"
"Rob Jonson\n"
"Pierre Baillet\n"
"Dominique Leuenberger\n"
"Andre Pang\n"
"Zoran Turalija\n"
"Akash Mehrotra\n"
"André Weber\n"
"Anthony Loiseau\n"
"Lukas Durfina\n"
"Xavier Marchesini\n"
"Cyril Mathé\n"
"Devin Heitmueller\n"
"Juho Vähä-Herttua\n"
"Ken Self\n"
"Alexis Ballier\n"
"Juha Jeronen\n"
"Nicolas Chauvet\n"
"Richard Hosking\n"
"Éric Lassauge\n"
"Marc Ariberti\n"
"Sébastien Toque\n"
"Tobias Güntner\n"
"Benoit Steiner\n"
"Michel Lespinasse\n"
"Carlo Calabrò\n"
"Cheng Sun\n"
"Michał Trzebiatowski\n"
"Brad Smith\n"
"Brendon Justin\n"
"Alexey Sokolov\n"
"Basos G\n"
"Philippe Morin\n"
"Steinar H. Gunderson\n"
"Vicente Jimenez Aguilar\n"
"Yuval Tze\n"
"Yves Duret\n"
"Benjamin Drung\n"
"Michael Hanselmann\n"
"Alex Merry\n"
"Damien Lucas\n"
"Grigori Goronzy\n"
"Richard Shepherd\n"
"Gaël Hendryckx\n"
"Michael Feurstein\n"
"Stephan Assmus\n"
"Adrien Grand\n"
"Colin Guthrie\n"
"David Menestrina\n"
"Dominique Martinet\n"
"Gleb Pinigin\n"
"Jason Luka\n"
"Luc Saillard\n"
"Luca Barbato\n"
"Mario Speiß\n"
"Pankaj Yadav\n"
"Ramiro Polla\n"
"Ronald Wright\n"
"Rui Zhang\n"
"Can Wu\n"
"Christophe Courtaut\n"
"FUJISAWA Tooru\n"
"Hannes Domani\n"
"Manol Manolov\n"
"Timothy B. Terriberry\n"
"Antoine Lejeune\n"
"Arnaud Schauly\n"
"Branko Kokanovic\n"
"Dylan Yudaken\n"
"Florian G. Pflug\n"
"François Revol\n"
"G Finch\n"
"Keary Griffin\n"
"Konstanty Bialkowski\n"
"Ming Hu\n"
"Philippe Coent\n"
"Przemyslaw Fiala\n"
"Tanguy Krotoff\n"
"Vianney BOYER\n"
"Casian Andrei\n"
"Chris Smowton\n"
"David Kaplan\n"
"Eugenio Jarosiewicz\n"
"Fabian Keil\n"
"Guillaume Poussel\n"
"John Peterson\n"
"Justus Piater\n"
"Mark Lee\n"
"Martin T. H. Sandsmark\n"
"Rune Botten\n"
"Søren Bøg\n"
"Toralf Niebuhr\n"
"Tristan Matthews\n"
"Angelo Haller\n"
"Aurélien Nephtali\n"
"Austin Burrow\n"
"Bill C. Riemers\n"
"Colin Delacroix\n"
"Cristian Maglie\n"
"Elminster2031\n"
"Jakub Wieczorek\n"
"John Freed\n"
"Mark Hassman\n"
"Martin Briza\n"
"Mike Houben\n"
"Romain Goyet\n"
"Adrian Yanes\n"
"Alexander Lakhin\n"
"Anatoliy Anischovich\n"
"Barry Wardell\n"
"Ben Hutchings\n"
"Besnard Jean-Baptiste\n"
"Brian Weaver\n"
"Clement Chesnin\n"
"David Geldreich\n"
"Diego Elio Pettenò\n"
"Diego Fernando Nieto\n"
"Georgi Chorbadzhiyski\n"
"Jon Stacey\n"
"Jonathan Rosser\n"
"Joris van Rooij\n"
"Kaloyan Kovachev\n"
"Katsushi Kobayashi\n"
"Kelly Anderson\n"
"Loren Merritt\n"
"Maciej Blizinski\n"
"Mark Bidewell\n"
"Miguel Angel Cabrera Moya\n"
"Niles Bindel\n"
"Samuel Pitoiset\n"
"Scott Caudle\n"
"Sean Robinson\n"
"Sergey Radionov\n"
"Simon Hailes\n"
"Stephen Parry\n"
"Sukrit Sangwan\n"
"Thierry Reding\n"
"Xavier Martin\n"
"Alex Converse\n"
"Alexander Bethke\n"
"Alexandre Ratchov\n"
"Andres Krapf\n"
"Andrey Utkin\n"
"Andri Pálsson\n"
"Andy Chenee\n"
"Anuradha Suraparaju\n"
"Benjamin Poulain\n"
"Brieuc Jeunhomme\n"
"Chris Clayton\n"
"Clément Lecigne\n"
"Cédric Cocquebert\n"
"Daniel Peng\n"
"Danny Wood\n"
"David K\n"
"Edouard Gomez\n"
"Emmanuel de Roux\n"
"Frode Tennebø\n"
"GBX\n"
"Gaurav Narula\n"
"Geraud CONTINSOUZAS\n"
"Hugues Fruchet\n"
"Jan Winter\n"
"Jean-François Massol\n"
"Jean-Philippe Grimaldi\n"
"Josh Watzman\n"
"Kai Lauterbach\n"
"Konstantin Bogdanov\n"
"Kuan-Chung Chiu\n"
"Kuang Rufan\n"
"Matthias Dahl\n"
"Michael McEll\n"
"Michael Ploujnikov\n"
"Mike Schrag\n"
"Nickolai Zeldovich\n"
"Nicolas Bertrand\n"
"Niklas Hayer\n"
"Olafs Vandāns\n"
"Olivier Gambier\n"
"Paul Corke\n"
"Ron Frederick\n"
"Rov Juvano\n"
"Sabourin Gilles\n"
"Sam Lade\n"
"Sandeep Kumar\n"
"Sasha Koruga\n"
"Sreng Jean\n"
"Sven Petai\n"
"Tomas Krotil\n"
"Tomer Barletz\n"
"Tristan Leteurtre\n"
"Wang Bo\n"
"maxime Ripard\n"
"xxcv\n"
"Adam Hoka\n"
"Adrian Knoth\n"
"Adrien Cunin\n"
"Alan Fischer\n"
"Alan McCosh\n"
"Alex Helfet\n"
"Alexander Terentyev\n"
"Alexandre Ferreira\n"
"Alina Friedrichsen\n"
"An L. Ber\n"
"Andreas Schlick\n"
"Andrew Schubert\n"
"Andrey Makhnutin\n"
"Arnaud Vallat\n"
"Asad Mehmood\n"
"Ashok Bhat\n"
"Austin English\n"
"Baptiste Coudurier\n"
"Benoit Calvez\n"
"Björn Stenberg\n"
"Blake Livingston\n"
"Brandon Brooks\n"
"Brian Johnson\n"
"Brian Kurle\n"
"Cezar Elnazli\n"
"Chris White\n"
"Christian Masus\n"
"Christoph Pfister\n"
"Christoph Seibert\n"
"Christopher Key\n"
"Christopher Rath\n"
"Claudio Ortelli\n"
"Cody Russell\n"
"Cristian Morales Vega\n"
"Dan Rosenberg\n"
"Daniel Marth\n"
"Daniel Tisza\n"
"Detlef Schroeder\n"
"Diego Biurrun\n"
"Dominik 'Rathann' Mierzejewski\n"
"Duncan Salerno\n"
"Edward Sheldrake\n"
"Elliot Murphy\n"
"Eren Inan Canpolat\n"
"Ernest E. Teem III\n"
"Etienne Membrives\n"
"Fargier Sylvain\n"
"Fathi Boudra\n"
"Felix Geyer\n"
"Filipe Azevedo\n"
"Finn Hughes\n"
"Florian Hubold\n"
"Florian Roeske\n"
"Frank Enderle\n"
"Frédéric Crozat\n"
"Georg Seifert\n"
"Gertjan Van Droogenbroeck\n"
"Gilles Chanteperdrix\n"
"Greg Farrell\n"
"Gregory Maxwell\n"
"Gwenole Beauchesne\n"
"Götz Waschk\n"
"Hans-Kristian Arntzen\n"
"Harry Sintonen\n"
"Iain Wade\n"
"Ibraheem Paredath\n"
"Isamu Arimoto\n"
"Ismael Luceno\n"
"James Bates\n"
"James Bond\n"
"James Turner\n"
"Janne Grunau\n"
"Janne Kujanpää\n"
"Jarmo Torvinen\n"
"Jason Scheunemann\n"
"Jeff Lu\n"
"Jeroen Ost\n"
"Joe Taber\n"
"Johann Ransay\n"
"Johannes Weißl\n"
"John Hendrikx\n"
"John Stebbins\n"
"Jonas Gehring\n"
"Joseph S. Atkinson\n"
"Juergen Lock\n"
"Julien 'Lta' BALLET\n"
"Julien / Gellule\n"
"Julien Humbert\n"
"Kamil Baldyga\n"
"Kamil Klimek\n"
"Karlheinz Wohlmuth\n"
"Kevin Anthony\n"
"Kevin DuBois\n"
"Lari Natri\n"
"Lorenzo Pistone\n"
"Lucas C. Villa Real\n"
"Lukáš Lalinský\n"
"Mal Graty\n"
"Malte Tancred\n"
"Martin Pöhlmann\n"
"Martin Zeman\n"
"Marton Balint\n"
"Mathew King\n"
"Mathieu Sonet\n"
"Matthew A. Townsend\n"
"Matthias Bauer\n"
"Mika Tiainen\n"
"Mike Cardillo\n"
"Mounir Lamouri (volkmar)\n"
"Natanael Copa\n"
"Nathan Phillip Brink\n"
"Nick Briggs\n"
"Nick Pope\n"
"Nil Geiswiller\n"
"Pascal Thomet\n"
"Pere Orga\n"
"Peter Bak Nielsen\n"
"Phil Roffe and David Grellscheid\n"
"Philip Sequeira\n"
"Pierre Souchay\n"
"Piotr Fusik\n"
"Pádraig Brady\n"
"R.M\n"
"Ralph Giles\n"
"Ramon Gabarró\n"
"Robert Forsman\n"
"Robert Jedrzejczyk\n"
"Robert Paciorek\n"
"Rolf Ahrenberg\n"
"Roman Pen\n"
"Ruud Althuizen\n"
"Samuli Suominen\n"
"Scott Lyons\n"
"Sebastian Birk\n"
"Sergey Puzanov\n"
"Sergio Ammirata\n"
"Sharad Dixit\n"
"Song Ye Wen\n"
"Stephan Krempel\n"
"Steven Kramer\n"
"Steven Sheehy\n"
"Sveinung Kvilhaugsvik\n"
"Sylvain Cadhillac\n"
"Sylver Bruneau\n"
"Takahito HIRANO\n"
"Theron Lewis\n"
"Thijs Alkemade\n"
"Tillmann Karras\n"
"Timo Paulssen\n"
"Timo Rothenpieler\n"
"Tobias Rapp\n"
"Tomasen\n"
"Tony Vankrunkelsven\n"
"Tristan Heaven\n"
"Varphone Wong\n"
"Vasily Fomin\n"
"Vikram Narayanan\n"
"Yannick Bréhon\n"
"Yavor Doganov\n"
"Yohann Martineau\n"
"dharani.prabhu.s\n"
"suheaven\n"
"wucan\n"
"김정은\n"
"Adam Sampson\n"
"Alexander Gall\n"
"Alex Antropoff\n"
"Alexis Guillard\n"
"Alex Izvorski\n"
"Amir Gouini\n"
"Andrea Guzzo\n"
"Andrew Flintham\n"
"Andrew Zaikin\n"
"Andy Lindsay\n"
"Arai/Fujisawa Tooru\n"
"Arkadiusz Miskiewicz\n"
"Arnaud Gomes-do-Vale\n"
"Arwed v. Merkatz\n"
"Barak Ori\n"
"Basil Achermann\n"
"Benjamin Mironer\n"
"Bill\n"
"Bob Maguire\n"
"Brian C. Wiles\n"
"Brian Raymond\n"
"Brian Robb\n"
"Carsten Gottbehüt\n"
"Carsten Haitzler\n"
"Charles Hordis\n"
"Chris Clepper\n"
"Christian Henz\n"
"Christof Baumgaertner\n"
"Christophe Burgalat\n"
"Christopher Johnson\n"
"Cian Duffy\n"
"Colin Simmonds\n"
"Damian Ivereigh\n"
"Daniel Fischer\n"
"Daniel Stränger\n"
"Danko Dolch\n"
"Dennis Lou\n"
"Dermot McGahon\n"
"Douglas West\n"
"Dugal Harris\n"
"Emmanuel Blindauer\n"
"Enrico Gueli\n"
"Enrique Osuna\n"
"Eren Türkay\n"
"Eric Dudiak\n"
"Espen Skoglund\n"
"Ethan C. Baldridge\n"
"François Seingier\n"
"Frans van Veen\n"
"Frédéric Ruget\n"
"Gerald Hansink\n"
"Gisle Vanem\n"
"Glen Gray\n"
"Goetz Waschk\n"
"Gregory Hazel\n"
"Gustaf Neumann\n"
"Hang Su\n"
"Hans Lambermont\n"
"Hans-Peter Jansen\n"
"Harris Dugal\n"
"Heiko Panther\n"
"Igor Helman\n"
"Isaac Osunkunle\n"
"Jan David Mol\n"
"Jan Gerber\n"
"Jan Van Boghout\n"
"Jasper Alias\n"
"Jean-Alexis Montignies\n"
"Jean-Baptiste Le Stang\n"
"Jeffrey Baker\n"
"Jeroen Massar\n"
"Jérôme Guilbaud\n"
"Johannes Buchner\n"
"Johen Michael Zorko\n"
"Johnathan Rosser\n"
"John Dalgliesh\n"
"John Paul Lorenti\n"
"Jörg\n"
"Joseph Tulou\n"
"Julien Blache\n"
"Julien Plissonneau Duquène\n"
"Julien Robert\n"
"Kenneth Ostby\n"
"Kenneth Self\n"
"Kevin H. Patterson\n"
"Koehler, Vitally\n"
"K. Staring\n"
"Lahiru Lakmal Priyadarshana\n"
"Laurent Mutricy\n"
"Leo Spalteholz\n"
"Loox Thefuture\n"
"Marc Nolette\n"
"Marco Munderloh\n"
"Mark Gritter\n"
"Markus Kern\n"
"Markus Kuespert\n"
"Martin Hamrle\n"
"Martin Kahr\n"
"Mateus Krepsky Ludwich\n"
"Mathias Kretschmer\n"
"Mats Rojestal\n"
"Matthias P. Nowak\n"
"Matthieu Lochegnies\n"
"Michael Mondragon\n"
"Michael S. Feurstein\n"
"Michel Lanners\n"
"Mickael Hoerdt\n"
"Miguel Angel Cabrera\n"
"Mikko Hirvonen\n"
"Moritz Bunkus\n"
"Nilmoni Deb\n"
"Olivier Houchard\n"
"Olivier Pomel\n"
"Ondrej Kuda aka Albert\n"
"Øyvind Kolbu\n"
"Pascal Levesque\n"
"Patrick Horn\n"
"Patrick McLean\n"
"Pauline Castets\n"
"Paul Mackerras\n"
"Peter Surda\n"
"Petr Vacek\n"
"Philippe Van Hecke\n"
"Pierre-Luc Beaudoin\n"
"Pierre Marc Dumuid\n"
"Régis Duchesne\n"
"Remco Poortinga\n"
"Rene Gollent\n"
"Rob Casey\n"
"Robson Braga Araujo\n"
"Roine Gustafsson\n"
"Roman Bednarek\n"
"Rudolf Cornelissen\n"
"Sašo Kiselkov\n"
"Sebastian Jenny\n"
"Shane Harper\n"
"Stefán Freyr Stefánsson\n"
"Steve Brown\n"
"Steven M. Schultz\n"
"Tapio Hiltunen\n"
"Thomas L. Wood\n"
"Thomas Mühlgrabner\n"
"Thomas Parmelan\n"
"Tim 'O Callagha\n"
"Tim Schuerewegen\n"
"Tong Ka Man\n"
"Torsten Spindler\n"
"Udo Richter\n"
"Vincent Dimar\n"
"Vincent Penne\n"
"Vitalijus Slavinskas\n"
"Vitaly V. Bursov\n"
"Vladimir Chernyshov\n"
"Wade Majors\n"
"Wallace Wadge\n"
"Watanabe Go\n"
"William Hawkins\n"
"Xavier Maillard\n"
"Ye zhang\n"
"Yuehua Zhao\n"
"Abylay Ospan\n"
"Adam Leggett\n"
"Adrian Haensler\n"
"Ago Allikmaa\n"
"Ajith Manjula Senarathne\n"
"Alain Degreffe\n"
"Alan Pope\n"
"Aleksandr Pasechnik\n"
"Alexandre Fernandez\n"
"Alexandre Pereira Nunes\n"
"Alexandre Perraud\n"
"Alex Peak\n"
"Alex Warhawk\n"
"Alex Woods\n"
"Allan Odgaard\n"
"Ancelot Mark Pinto\n"
"Andrea Giudiceandrea\n"
"Andreas Hartmetz\n"
"Andreas Mieke\n"
"André Silva\n"
"Andrew Clayton\n"
"Andrey Gursky\n"
"Andrii Zui\n"
"Andy Tather\n"
"Antti Ajanki\n"
"Ara Qadir\n"
"Arjun Sreedharan\n"
"Arne de Bruijn\n"
"Arun Pandian G\n"
"A S Alam\n"
"Avani Sharma\n"
"Avishay Spitzer\n"
"Bastien Penavayre\n"
"Benjamin Adolphi\n"
"Ben Littler\n"
"Benoit du Payrat\n"
"Benoît Noël du Payrat\n"
"Bernd Kuhls\n"
"Boris Egorov\n"
"Boy van Amstel\n"
"Brian Schmidt\n"
"Brion Vibber\n"
"Cameron Mozie\n"
"Carlos Fenollosa\n"
"Carola Nitz\n"
"Christian Suloway\n"
"Clemens Werther\n"
"C.W. Betts\n"
"Daniel Amm\n"
"Daniel Verkamp\n"
"Darko Jankovic\n"
"Darrell Walisser\n"
"David Robison\n"
"David R Robison\n"
"Dennis Hamester\n"
"Derek Buitenhuis\n"
"Diogo Silva\n"
"Dominko Azdajic\n"
"Donald Campbell\n"
"Doney den Ouden\n"
"Duncan McNamara\n"
"Duncan McNAMARA\n"
"Elodie Thomann\n"
"Emeric Grange\n"
"Eric Engestrom\n"
"Etienne BRATEAU\n"
"Eugen Geist\n"
"Fabian Yamaguchi\n"
"Fabrizio Ge\n"
"Fabrizio Gennari\n"
"Fahad Al-Saidi\n"
"Felix Abecassis\n"
"Florent Pillet\n"
"Forteve Zepushisti\n"
"Frank Praznik\n"
"Gabriel de Perthuis\n"
"Gal Vinograd\n"
"Gaurav Pruthi\n"
"Geoffrey Métais\n"
"Gian Marco Sibilla\n"
"Gilles Sabourin\n"
"Gina Dobrescu\n"
"Gonzalo Higuera Díaz\n"
"Goran Dokic\n"
"Guillaume Gomez\n"
"Harald Sitter\n"
"Heorhi Valakhanovich\n"
"Ian Chamberlain\n"
"Ibrahima SARR\n"
"Igor Prokopenkov\n"
"Ion Agorria\n"
"Jarrad Whitaker\n"
"Jean-Yves Avenard\n"
"Jed Smith\n"
"Jérémy Carrier\n"
"Jeremy Huddleston Sequoia\n"
"Jerome Forissier\n"
"Jim Bankoski\n"
"Jonas Lundqvist\n"
"Jonatan \"jaw\" Wallmander\n"
"Jonathan Calmels\n"
"Jonathan Heard\n"
"Jonathan McGowan\n"
"Jonathan Thambidurai\n"
"Joni Räsänen\n"
"Josef Andersson\n"
"Joseph DeVore\n"
"Julian Scheel\n"
"Justin Kim\n"
"Kaarlo Räihä\n"
"Kamil Rytarowski\n"
"Kazuki Yamaguchi\n"
"Konstantin K. Beliak\n"
"Konstantinos Tsanaktsidis\n"
"Konstantin Pavlov\n"
"Kornel Lesiński\n"
"Olivier Langlois\n"
"Lochlin Duperron\n"
"Lukas Juhrich\n"
"Lyndon Brown\n"
"Marc Aldorasi\n"
"Marcel Schnirring\n"
"Marc Etcheverry\n"
"Mariusz Wasak\n"
"Mark Becwar\n"
"Martell Malone\n"
"Mathieu Malaterre\n"
"Mathieu Parent\n"
"Mathieu Velten\n"
"Matthias Keiser\n"
"Matthias Treydte\n"
"Max Dilipovich\n"
"Maxim Bublis\n"
"Maxime CHAPELET\n"
"Maxime Mouchet\n"
"Michael Tänzer\n"
"Miha Sokolov\n"
"Mohammed (Shaan) Huzaifa Danish\n"
"Moti Zilberman\n"
"Nathan Egge\n"
"Niklas Haas\n"
"Odd-Arild Kristensen\n"
"O. Hartmann\n"
"Olaf Hering\n"
"Oliver Collyer\n"
"Paul B Mahol\n"
"Paul Clark\n"
"Paulo Vitor Magacho da Silva\n"
"Pavol Babincak\n"
"Paweł Stankowski\n"
"Petter Reinholdtsen\n"
"Philip Höhlein\n"
"Pierre-Hugues Husson\n"
"Pierre Lamot\n"
"Pyry Kontio\n"
"Radek Vybiral\n"
"Rafael Waldo Delgado Doblas\n"
"Rajeesh K V\n"
"Ray Tiley\n"
"Reka Inovan\n"
"Remita Amine\n"
"Ricardo Ribalda Delgado\n"
"Richard Diamond\n"
"Rinat Ibragimov\n"
"Robert Mourning\n"
"Romain Bentz\n"
"Romain Fliedel\n"
"Romain Vimont\n"
"Ronald S. Bultje\n"
"Ross Finlayson\n"
"Sam Malone\n"
"Samuel Martin\n"
"Samuel Thibault\n"
"Sanchit Arora\n"
"Santiago Gimeno\n"
"Sebastian Ramacher\n"
"Sebastian Roth\n"
"Sergey Bolshakov\n"
"Shaleen Jain\n"
"Shlomi Fish\n"
"Simona-Marinela Prodea\n"
"Stanislas Plessia\n"
"Stefan Pöschel\n"
"Steven Toth\n"
"Sushma Reddy\n"
"Takahito Hirano\n"
"T. Chomphuming\n"
"Thierry Foucu\n"
"Thomas Nigro\n"
"Tim Allen\n"
"Tim Walker\n"
"Tobias Conradi\n"
"Tony Gaillard\n"
"Benoît Tuduri\n"
"Tzu-Jung Lee\n"
"Uwe L. Korn\n"
"Valentin Deniaud\n"
"Valentin Vetter\n"
"Valter Correia\n"
"Vianney Boyer\n"
"Victorien Le Couviour--Tuffet\n"
"Vikram Fugro\n"
"Vinson Lee\n"
"Wayne McDougall\n"
"Wieland Hoffmann\n"
"Wills Wang\n"
"Xabier Aramendi\n"
"Yaşar Tay\n"
"Yidong Ren\n"
"Yuudai Yamashigi\n"
"Zhao Zhili\n"
"أحمد المحم ودي (Ahmed El-Mahmoudy)\n"
"Баярсайхан Энхтайван\n"
"Сергей Дарьичев\n"
"\n"
"Artwork\n"
"-------\n"
"Damien Erambert\n"
"Daniel Dreibrodt, aka aLtgLasS\n"
"David Weber\n"
"Davor Orel\n"
"Dominic Spitaler\n"
"Doney den Ouden\n"
"Eurodata Computer Club\n"
"Geoffrey Roussel\n"
"Joeri van Dooren\n"
"kty0ne\n"
"Max Rudberg\n"
"Richard Øiestad\n"
"Simon Damkjær Andersen\n"
"Tom Bigelajzen\n"
"Vincent van den Heuvel\n"
"\n"
"Documentation\n"
"-------------\n"
"Bill Eldridge\n"
"\n"
"Localization\n"
"------------\n"
"Abdul Fousan - Tamil\n"
"A. Decorte - Friulian\n"
"A. Regnander - Swedish\n"
"Adem Gunes - Turkish\n"
"Adi Nugroho - Tagalog\n"
"Adnan Memija - Bosnian\n"
"airplanez - Korean\n"
"Ajith Manjula - Sinhala\n"
"Aled Powell - Welsh\n"
"Alexander Didebulidze - Georgian\n"
"Alexander Henket - Dutch\n"
"Alexander Jansen - Norwegian Bokmål\n"
"Alexander Lakhin - Russian\n"
"Alexey Lugin - Ukrainian\n"
"Alexey Salmin - Russian\n"
"Alfred John - Acoli\n"
"Amanpreet Singh Alam - Punjabi\n"
"André de Barros Martins Ribeiro - Brazilian portuguese\n"
"Andrey Brilevskiy - Russian\n"
"Andrey Wolk - Russian\n"
"Andri Pálsson - Icelandic\n"
"Andriy Bandura - Ukrainian\n"
"Anh Phan - Vietnamese\n"
"Aniket Eknath Kudale - Marathi\n"
"Animesh Swar - Nepalese\n"
"Aputsiaĸ Niels Janussen - Danish\n"
"Ara Bextiyar - Sorani (Kurdish)\n"
"Ari Constâncio - Portuguese\n"
"Arkadiusz Lipiec - Polish\n"
"Ask Hjorth Larsen - Danish\n"
"Audrey Prevost - French\n"
"Auk Piseth - Khmer\n"
"Bayarsaikhan Enkhtaivan Баярсайхан Энхтайван - Mongolian\n"
"Biraj Karmakar - Bengali (India)\n"
"Bruno Queirós - Portuguese\n"
"Bruno Vella - Italian\n"
"Caner Başaran - Turkish\n"
"Carlo Calabrò - Italian\n"
"Chandan Kumar - Hindi\n"
"Chesús Daniel Trigo - Aragonese\n"
"Christoph Miebach - German\n"
"Chynggyz Jumaliev - Kirgyz\n"
"Circo Radu - Romanian\n"
"Cristian Secară - Romanian\n"
"Daniel Nylander - Swedish\n"
"Daniel Winzen - German\n"
"David González - Spanish\n"
"David Planella - Catalan\n"
"Dean Lee - Simplified Chinese\n"
"Denis Arnaud - Breton\n"
"Derk-Jan Hartman - Dutch\n"
"DirektX - Hungarian\n"
"Dominko Aždajić - Croatian\n"
"Dylan Aïssi - French\n"
"Đorđe Vasiljević - Serbian\n"
"Eduard Babayan - Armenian\n"
"Eero - Estonian\n"
"Eirik U. Birkeland - Norwegian Nynorsk\n"
"Elizabeth Da Conceicao Baptista - Tetum\n"
"Emilio Sepúlveda - Interlingua\n"
"Emin Mastizada - Azerbaijani\n"
"Éric Lassauge - French\n"
"Farzaneh Sarafraz - Persian\n"
"Florence Tushabe - Chiga\n"
"Fouzia Bourai - Arabic\n"
"Frank Chao - Traditional Chinese\n"
"Freyr Gunnar Ólafsson - Icelandic\n"
"Friedel Wolff - Afrikaans\n"
"Fumio Nakayama - Japanese\n"
"Gabor Kelemen - Hungarian\n"
"Gaurav Kumar - Hindi\n"
"Gaëtan Rousseaux - Walloon\n"
"Ghjuvan Pasquinu - Corsican\n"
"Goce Manevski - Macedonian\n"
"Golam Maruf Oovee - Bengali\n"
"Gonçalo Cordeiro - Galician\n"
"Gorana Milicevic - Serbian\n"
"Goswami Hardikpuri Kishorpuri - Gujarati\n"
"Haakon Meland Eriksen - Norwegian\n"
"Han HoJoong - Korean\n"
"Hardik Kishorpuri Goswami - Gujarati\n"
"Hemanta Nandi - Bengali (India)\n"
"Huw Waters - Welsh\n"
"H.Shalitha Vikum - Sinhala\n"
"Ibrahima Sarr - Fulah\n"
"Ingmārs Dīriņš - Latvian\n"
"Israt Jahan - Bengali\n"
"Ivar Smolin - Estonian\n"
"Iván Seoane Pardo - Galician\n"
"Ivo Ivanov - Bulgarian\n"
"Iñaki Larrañaga Murgoitio - Basque\n"
"Iñigo Varela - Asturian; Bable\n"
"Jakub Žáček - Czech\n"
"James Olweny - Ganda\n"
"Jamil Ahmed - Bengali\n"
"Javier Varela - Spanish\n"
"Jean-Pierre Kuypers - French\n"
"Jens Seidel - German\n"
"Joao Almeida - Portuguese\n"
"Joel Arvidsson - Swedish\n"
"jogijs - Latvian\n"
"Jonas Larsen - Danish\n"
"Jon Stødle - Norwegian Nynorsk\n"
"Jouni Kähkönen - Finnish\n"
"Juha Jeronen - Finnish\n"
"Julen Ruiz Aizpuru - Basque\n"
"Kai Hermann - German\n"
"Kamil Páral - Czech\n"
"Kang Jeong-Hee - Korean\n"
"Kasper Tvede - Danish\n"
"Kaya Zeren - Turkish\n"
"Kenneth Nielsen - Danish\n"
"Khin Mi Mi Aung - Burmese\n"
"Khoem Sokhem - Khmer\n"
"Kola - Albanian\n"
"Kypchak Kypchak - Kazakh\n"
"Laurent Jonqueres - Occitan\n"
"Loba Yeasmeen - Bengali\n"
"Lorena Gomes - Catalan\n"
"Lorenzo Porta - Italian\n"
"Luqman Hakim - Indonesian\n"
"L. Balasubramaniam - Hindi\n"
"Mahrazi Mohd Kamal - Malay\n"
"Manolis Stefanis - Modern Greek\n"
"Manuela Silva/Alfredo Silva - Portuguese\n"
"Marián Hikaník - Slovak\n"
"Mario Siegmann - German\n"
"Marko Uskokovic - Serbian\n"
"Martin Srebotnjak - Slovenian\n"
"Martin Zicha - Czech\n"
"Matej Urbančič - Slovenian\n"
"Mathias C. Berens, welcome-soft - German\n"
"Mattias Põldaru - Estonian\n"
"Md. Rezwan Shahid - Bengali\n"
"Meelad Zakaria - Persian\n"
"Michael Bauer - Scottish Gaelic\n"
"Michal Halenka - Czech\n"
"Michał Trzebiatowski - Polish\n"
"Miguel Sousa - Portuguese\n"
"Mihkel Kirjutas - Estonian\n"
"Mindaugas Baranauskas - Lithuanian\n"
"Miroslav Oujeský - Czech\n"
"Morten Brix Pedersen - Danish\n"
"Mustafa Sandal - Czech\n"
"Myckel Habets - Dutch\n"
"Namhyung Kim - Korean\n"
"Niels Fanøe - Danish\n"
"Niklas 'Nille' Åkerström - Swedish\n"
"Olav Dahlum - Norwegian Bokmål\n"
"Oleksandr Natalenko - Ukrainian\n"
"Omer Ensari - Kurmanji (Kurdish)\n"
"Osama Khalid - Arabic\n"
"Otto Kekäläinen - Finnish\n"
"Paras Nath Chaudhary - Nepali\n"
"Pasindu Kavinda - Sinhala\n"
"Pau Iranzo - Catalan\n"
"Paula Iglesias - Galician\n"
"Pedro Valadares - Portuguese\n"
"Peter Jespersen - Danish\n"
"Petr Šimáček - Czech\n"
"Phan Anh - Vietnamese\n"
"Philipp Weissenbacher - German\n"
"Pittayakom Saingtong - Thai\n"
"Prasannajit Acharya - Oriya\n"
"Praveen Illa - Telugu\n"
"Predrag Ljubenović - Serbian\n"
"Pyae Sone - Burmese\n"
"Rajnikant Kumbhar - Marathi\n"
"Ricardo Perdigão - Portuguese\n"
"Ricardo Pérez López - Spanish\n"
"Roustam Ghizdatov - Russian\n"
"Ruei-Yuan Lu - Traditional Chinese\n"
"Saad Liaquat Kiani - Urdu\n"
"Sadia Afroz - Bengali\n"
"Said Marjan Zazai - Pashto\n"
"Salar Khalilzadeh - Persian\n"
"Sam Askari - Spanish\n"
"Sam Hocevar - British\n"
"Samuel Hocevar - French\n"
"Saúl Ortega - Spanish\n"
"Savvas Nesseris - Modern Greek\n"
"Sayan Chowdhury - Hindi\n"
"Seanán Ó Coistín - Irish\n"
"Semsudin Abdic - Bosnian\n"
"Shambhu Kumar - Hindi\n"
"Shantanu Sarkar - Hindi\n"
"Shashi Ranjan - Hindi\n"
"Siarhei Daryichau Дар'ічаў Сяргей - Belarusian\n"
"Sidney Doria - Brazilian Portuguese\n"
"Sigmund Augdal - Norwegian Bokmål\n"
"Simos Xenitellis - Modern Greek\n"
"Sipho Sibiya - Zulu\n"
"Sok Sophea - Khmer\n"
"Solomon Gizaw - Amharic\n"
"Sreejith P - Malayalam\n"
"Suraj Kawade - Marathi\n"
"Stian Jørgensrud - Norwegian Bokmål\n"
"Sveinn í Felli - Icelandic\n"
"Tadashi Jokagi - Japanese\n"
"Tarsem Singh - Hindi\n"
"Thanakrit Chomphuming - Thai\n"
"Tero Pelander - Finnish\n"
"Thomas De Rocker - Dutch\n"
"Thomas Graf - gettext support, German\n"
"Tomáš Chvátal - Czech\n"
"Tòni Galhard - Occitan\n"
"Umesh Agarwal - Bengali (India)\n"
"Umidjon Almasov - Uzbek\n"
"Václav Pavlíček - Czech\n"
"Valek Filippov - Russian\n"
"Vicente Jimenez Aguilar - Spanish\n"
"Vincenzo Reale - Italian\n"
"Vít Pelčák - Czech\n"
"viyyer - Hindi\n"
"Vladimir Yermolayev - Russian\n"
"Vojtěch Smejkal - Czech\n"
"Wei Mingzhi - Simplified Chinese\n"
"Xènia Albà Cantero - Catalan\n"
"Xuacu Saturio - Asturian\n"
"Yaron Shahrabani - Hebrew\n"
"Yaşar Tay - Turkish\n"
"Yhal Htet Aung - Burmese\n"
"Yogesh K S - Kannada\n"
"Yoyo - Simplified Chinese\n"
"Yuksel Yildirim - Turkish\n"
"Zabeeh Khan - Pashto\n"
"Zhang Tong - Chinese\n"
;
